@@ -189,13 +189,13 @@ def get_windows_env() -> Mapping[str, str | None]:
             "ALLUSERSPROFILE",
             "APPDATA",
             "COMMONPROGRAMFILES",
-            "COMMONPROGRAMFILES(x86)",
+            "COMMONPROGRAMFILES(X86)",
             "DEFAULTUSERPROFILE",
             "HOMEPATH",
             "PATHEXT",
             "PROFILESFOLDER",
             "PROGRAMFILES",
-            "PROGRAMFILES(x86)",
+            "PROGRAMFILES(X86)",
             "SYSTEM",
             "SYSTEM16",
             "SYSTEM32",
@@ -711,7 +711,8 @@ def version(  # noqa: C901
     release_notes = generate_release_notes(
         hvcs_client,
         release_history.released[new_version],
-        template_dir=runtime.template_dir,
+        runtime.template_dir,
+        history=release_history,
     )
 
     exception: Exception | None = None
