@@ -1,9 +1,7 @@
 from __future__ import annotations
 
-import base64
 import fnmatch
 import glob
-import mimetypes
 import os
 import re
 from typing import TYPE_CHECKING
@@ -13,6 +11,7 @@ from urllib.parse import urlencode
 import pytest
 import requests_mock
 from requests import HTTPError, Response, Session
+from requests.auth import _basic_auth_str
 
 from semantic_release.hvcs.github import Github
 from semantic_release.hvcs.token_auth import TokenAuth
@@ -511,6 +510,7 @@ def test_should_create_release_using_token_or_netrc(
     default_netrc_username: str,
     default_netrc_password: str,
     netrc_file: NetrcFileFn,
+    clean_os_environment: dict[str, str],
 ):
     # Setup
     default_gh_client.token = token
@@ -532,26 +532,26 @@ def test_should_create_release_using_token_or_netrc(
         "prerelease": False,
     }
 
-    encoded_auth = (
-        base64.encodebytes(
-            f"{default_netrc_username}:{default_netrc_password}".encode()
-        )
-        .decode("ascii")
-        .strip()
+    expected_request_headers = set(
+        (
+            {"Authorization": f"token {token}"}
+            if token
+            else {
+                "Authorization": _basic_auth_str(
+                    default_netrc_username, default_netrc_password
+                )
+            }
+        ).items()
     )
 
-    expected_request_headers = (
-        {"Authorization": f"token {token}"}
-        if token
-        else {"Authorization": f"Basic {encoded_auth}"}
-    ).items()
-
     # create netrc file
     netrc = netrc_file(machine=default_gh_client.DEFAULT_API_DOMAIN)
 
+    mocked_os_environ = {**clean_os_environment, "NETRC": netrc.name}
+
     # Monkeypatch to create the Mocked environment
     with requests_mock.Mocker(session=default_gh_client.session) as m, mock.patch.dict(
-        os.environ, {"NETRC": netrc.name}, clear=True
+        os.environ, mocked_os_environ, clear=True
     ):
         # mock the response
         m.register_uri(
@@ -570,9 +570,23 @@ def test_should_create_release_using_token_or_netrc(
         assert expected_num_requests == len(m.request_history)
         assert expected_http_method == m.last_request.method
         assert expected_request_url == m.last_request.url
-        assert expected_request_headers <= m.last_request.headers.items()
         assert expected_request_body == m.last_request.json()
 
+        # calculate the match between expected and actual headers
+        # We are not looking for an exact match, just that the headers we must have exist
+        shared_headers = expected_request_headers.intersection(
+            set(m.last_request.headers.items())
+        )
+        assert expected_request_headers == shared_headers, str.join(
+            "\n",
+            [
+                "Actual headers are missing some of the expected headers",
+                f"Matching: {shared_headers}",
+                f"Missing: {expected_request_headers - shared_headers}",
+                f"Extra: {set(m.last_request.headers.items()) - expected_request_headers}",
+            ],
+        )
+
 
 def test_request_has_no_auth_header_if_no_token_or_netrc():
     tag = "v1.0.0"
@@ -746,11 +760,17 @@ def test_create_or_update_release_when_create_succeeds(
 ):
     tag = "v1.0.0"
     with mock.patch.object(
-        default_gh_client, "create_release", return_value=mock_release_id
+        default_gh_client,
+        default_gh_client.create_release.__name__,
+        return_value=mock_release_id,
     ) as mock_create_release, mock.patch.object(
-        default_gh_client, "get_release_id_by_tag", return_value=mock_release_id
+        default_gh_client,
+        default_gh_client.get_release_id_by_tag.__name__,
+        return_value=mock_release_id,
     ) as mock_get_release_id_by_tag, mock.patch.object(
-        default_gh_client, "edit_release_notes", return_value=mock_release_id
+        default_gh_client,
+        default_gh_client.edit_release_notes.__name__,
+        return_value=mock_release_id,
     ) as mock_edit_release_notes:
         # Execute in mock environment
         result = default_gh_client.create_or_update_release(
@@ -778,15 +798,15 @@ def test_create_or_update_release_when_create_fails_and_update_succeeds(
 
     with mock.patch.object(
         default_gh_client,
-        "create_release",
+        default_gh_client.create_release.__name__,
         side_effect=not_found,
     ) as mock_create_release, mock.patch.object(
         default_gh_client,
-        "get_release_id_by_tag",
+        default_gh_client.get_release_id_by_tag.__name__,
         return_value=mock_release_id,
     ) as mock_get_release_id_by_tag, mock.patch.object(
         default_gh_client,
-        "edit_release_notes",
+        default_gh_client.edit_release_notes.__name__,
         return_value=mock_release_id,
     ) as mock_edit_release_notes:
         # Execute in mock environment
@@ -812,11 +832,17 @@ def test_create_or_update_release_when_create_fails_and_no_release_for_tag(
     not_found.response.status_code = 404
 
     with mock.patch.object(
-        default_gh_client, "create_release", side_effect=not_found
+        default_gh_client,
+        default_gh_client.create_release.__name__,
+        side_effect=not_found,
     ) as mock_create_release, mock.patch.object(
-        default_gh_client, "get_release_id_by_tag", return_value=None
+        default_gh_client,
+        default_gh_client.get_release_id_by_tag.__name__,
+        return_value=None,
     ) as mock_get_release_id_by_tag, mock.patch.object(
-        default_gh_client, "edit_release_notes", return_value=None
+        default_gh_client,
+        default_gh_client.edit_release_notes.__name__,
+        return_value=None,
     ) as mock_edit_release_notes:
         # Execute in mock environment expecting an exception to be raised
         with pytest.raises(ValueError):
@@ -945,7 +971,6 @@ def test_upload_release_asset_fails(
 ):
     # Setup
     label = "abc123"
-    urlparams = {"name": example_changelog_md.name, "label": label}
     upload_url = "{up_url}/repos/{owner}/{repo_name}/releases/{release_id}".format(
         up_url=github_upload_url,
         owner=default_gh_client.owner,
@@ -956,18 +981,6 @@ def test_upload_release_asset_fails(
         "status": "ok",
         "upload_url": upload_url,
     }
-    changelog_data_mime_type = (
-        mimetypes.guess_type(example_changelog_md.resolve(), strict=False)[0]
-        or "application/octet-stream"
-    )
-    expected_num_requests = 2
-    expected_http_method = "POST"
-    expected_upload_request_url = "{url}?{params}".format(
-        url=upload_url,
-        params=urlencode(urlparams),
-    )
-    expected_upload_request_headers = {"Content-Type": changelog_data_mime_type}.items()
-    expected_changelog = example_changelog_md.read_bytes()
 
     with requests_mock.Mocker(session=default_gh_client.session) as m:
         # mock the responses
@@ -987,14 +1000,6 @@ def test_upload_release_asset_fails(
                 label=label,
             )
 
-        # Evaluate (expected -> actual)
-        assert m.called
-        assert expected_num_requests == len(m.request_history)
-        assert expected_http_method == m.last_request.method
-        assert expected_upload_request_url == m.last_request.url
-        assert expected_upload_request_headers <= m.last_request.headers.items()
-        assert expected_changelog == m.last_request.body
-
 
 # Note - mocking as the logic for uploading an asset
 # is covered by testing above, no point re-testing.
@@ -1006,10 +1011,10 @@ def test_upload_dists_when_release_id_not_found(default_gh_client):
     # Set up mock environment
     with mock.patch.object(
         default_gh_client,
-        "get_release_id_by_tag",
+        default_gh_client.get_release_id_by_tag.__name__,
         return_value=None,
     ) as mock_get_release_id_by_tag, mock.patch.object(
-        default_gh_client, "upload_release_asset"
+        default_gh_client, default_gh_client.upload_release_asset.__name__
     ) as mock_upload_release_asset:
         # Execute method under test
         result = default_gh_client.upload_dists(tag, path)
@@ -1051,11 +1056,11 @@ def test_upload_dists_when_release_id_found(
     # Set up mock environment
     with mocked_globber, mocked_isfile, mock.patch.object(
         default_gh_client,
-        "get_release_id_by_tag",
+        default_gh_client.get_release_id_by_tag.__name__,
         return_value=release_id,
     ) as mock_get_release_id_by_tag, mock.patch.object(
         default_gh_client,
-        "upload_release_asset",
+        default_gh_client.upload_release_asset.__name__,
         side_effect=upload_statuses,
     ) as mock_upload_release_asset:
         # Execute method under test
